# docraptor

DocRaptor - the Ruby gem for the DocRaptor

A native client library for the DocRaptor HTML to PDF/XLS service.

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.0
- Package version: 3.1.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build docraptor.gemspec
```

Then either install the gem locally:

```shell
gem install ./docraptor-3.1.0.gem
```

(for development, run `gem install --dev ./docraptor-3.1.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'docraptor', '~> 3.1.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'docraptor', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'docraptor'

# Setup authorization
DocRaptor.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = DocRaptor::DocApi.new
doc = DocRaptor::Doc.new({name: 'name_example', document_type: 'pdf'}) # Doc | 

begin
  result = api_instance.create_async_doc(doc)
  p result
rescue DocRaptor::ApiError => e
  puts "Exception when calling DocApi->create_async_doc: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.docraptor.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DocRaptor::DocApi* | [**create_async_doc**](docs/DocApi.md#create_async_doc) | **POST** /async_docs | 
*DocRaptor::DocApi* | [**create_doc**](docs/DocApi.md#create_doc) | **POST** /docs | 
*DocRaptor::DocApi* | [**create_hosted_async_doc**](docs/DocApi.md#create_hosted_async_doc) | **POST** /hosted_async_docs | 
*DocRaptor::DocApi* | [**create_hosted_doc**](docs/DocApi.md#create_hosted_doc) | **POST** /hosted_docs | 
*DocRaptor::DocApi* | [**expire**](docs/DocApi.md#expire) | **PATCH** /expire/{id} | 
*DocRaptor::DocApi* | [**get_async_doc**](docs/DocApi.md#get_async_doc) | **GET** /download/{id} | 
*DocRaptor::DocApi* | [**get_async_doc_status**](docs/DocApi.md#get_async_doc_status) | **GET** /status/{id} | 


## Documentation for Models

 - [DocRaptor::AsyncDoc](docs/AsyncDoc.md)
 - [DocRaptor::Doc](docs/Doc.md)
 - [DocRaptor::DocStatus](docs/DocStatus.md)
 - [DocRaptor::PrinceOptions](docs/PrinceOptions.md)


## Documentation for Authorization


Authentication schemes defined for the API:
### basicAuth

- **Type**: HTTP basic authentication

